'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.isValidTimeRangeString = exports.isValidTimeString = exports.isValidDayName = exports.isValidDateString = undefined;

var _Day = require('./Day');

var isValidDateString = exports.isValidDateString = function isValidDateString(string) {
    var parts = string.split('-');

    if (parts.length !== 3) {
        return false;
    }

    var year = parseInt(parts[0]);
    var month = parseInt(parts[1]);
    var day = parseInt(parts[2]);

    // http://stackoverflow.com/a/8390325/999733

    if (month < 1 || month > 12) {
        return false;
    }

    if (day < 1 || day > 31) {
        return false;
    }

    if ((month == 4 || month == 6 || month == 9 || month == 11) && day > 30) {
        return false;
    }

    if (month == 2 && (year % 400 == 0 || year % 4 == 0) && year % 100 != 0 && day > 29) {
        return false;
    }

    if (month == 2 && year % 100 == 0 && day > 29) {
        return false;
    }

    if (month == 2 && day > 28) {
        return false;
    }

    return true;
};

var isValidDayName = exports.isValidDayName = function isValidDayName(name) {
    return (0, _Day.days)().filter(function (day) {
        return day === name;
    }).length > 0;
};

var isValidTimeString = exports.isValidTimeString = function isValidTimeString(string) {
    return string.match('^(([0-1][0-9])|(2[0-4])):[0-5][0-9]$');
};

var isValidTimeRangeString = exports.isValidTimeRangeString = function isValidTimeRangeString(string) {
    var times = string.split('-');

    if (times.length !== 2) {
        return false;
    }

    return isValidTimeString(times[0]) && isValidTimeString(times[1]);
};

exports.default = {
    isValidDateString: isValidDateString,
    isValidDayName: isValidDayName,
    isValidTimeString: isValidTimeString,
    isValidTimeRangeString: isValidTimeRangeString
};